%
% video_test.m - creates an animation and saves it to an mp4 video file
%
% The program will create a video file called test.mp4 containging a moving
% ball and its 'reflection' around the x axis. The program sets the
% resolution to 640x480 pixels and the frame rate to be 30 fps.

close all
clear
clc

%%%%%%   Initialize Video File   %%%%%%%

figure('units','pixels','position',[0 0 640 480])    % set plot size in pixels
vid_file = VideoWriter('test.mp4','MPEG-4');         % use mp4 format for video file
vid_file.FrameRate = 30;                             % playback speed
open(vid_file);                                      % open video file


%%%%%%   Calculate (x,y) positions of moving ball   %%%%%%%

x = linspace(0,2,200);
y = sin(2*pi*x);


%%%%%   Loop Over Movie Frames   %%%%%

for j=1:length(x)
    
    % Plot position of ball and its reflection around x axis
    plot(x(j),y(j),'ro','MarkerSize',20,'MarkerFaceColor','r');
    hold on
    plot(x(j),-y(j),'ro','MarkerSize',20,'MarkerFaceColor','g');
    hold off

    % set axis limits and hide axes
    xlim([-.5  2.5])
    ylim([-1.5 1.5])
    axis off
        
    % write plot to video file
    FRAME(j) = getframe(gcf);
    writeVideo(vid_file, FRAME(j));

end

%%%%%%%%%%   Close Video File   %%%%%%%%%%

close(vid_file);



